package DBIx::Class::TimeStamp::TimeMomentX_BOKUTIN;
# ABSTRACT: DBIx::Class::TimeStamp compatible except s/DateTime/TimeMoment/
$DBIx::Class::TimeStamp::TimeMomentX_BOKUTIN::VERSION = '0.17';
use strict;
use warnings;
use base qw(DBIx::Class);

use Time::MomentX::BOKUTIN;

__PACKAGE__->load_components( qw/DynamicDefault InflateColumn::TimeMomentX_BOKUTIN/ );

sub add_columns {
    my ($self, @cols) = @_;
    my @columns;

    while (my $col = shift @cols) {
        my $info = ref $cols[0] ? shift @cols : {};

        if ( delete $info->{set_on_create} ) {
            $info->{dynamic_default_on_create} = 'get_timestamp';
        }

        if ( delete $info->{set_on_update} ) {
            $info->{dynamic_default_on_update} = 'get_timestamp';
        }

        push @columns, $col => $info;
    }

    return $self->next::method(@columns);
}

# _current_timestamp を探すのは created_at と updated_at を同じにしたい為

sub insert {
    my $self = shift;
    $self->{_current_timestamp} = undef;
    my $ret = $self->next::method(@_);
    delete $self->{_current_timestamp};
    $ret;
}

sub update {
    my $self = shift;
    $self->{_current_timestamp} = undef;
    my $ret = $self->next::method(@_);
    delete $self->{_current_timestamp};
    $ret;
}

sub get_timestamp {
    my $self = shift;
    if (exists $self->{_current_timestamp}) {
        $self->{_current_timestamp} ||= tmx->now;
    }
    else {
        tmx->now;
    }
}

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

DBIx::Class::TimeStamp::TimeMomentX_BOKUTIN - DBIx::Class::TimeStamp compatible except s/DateTime/TimeMoment/

=cut
