package Time::Moment::Role::TimeZone::Fast;
$Time::Moment::Role::TimeZone::Fast::VERSION = '0.17';
use Role::Tiny;
use Carp ();
use Time::Local ();
use Time::TZOffset ();

requires qw(epoch offset with_offset_same_instant with_offset_same_local
  utc_rd_as_seconds utc_rd_values local_rd_as_seconds local_rd_values utc_year);

sub with_time_zone_offset_same_instant {
  my ($self, $tz) = @_;
  Carp::croak "Invalid time zone object $tz" unless defined $tz and $tz->can('offset_for_datetime');
  return $self->with_offset_same_instant($tz->offset_for_datetime($self) / 60);
}

sub with_time_zone_offset_same_local {
  my ($self, $tz) = @_;
  Carp::croak "Invalid time zone object $tz" unless defined $tz and $tz->can('offset_for_local_datetime');
  my ($offset, $error);
  { local $@;
    unless (eval { $offset = $tz->offset_for_local_datetime($self); 1 }) {
      $error = $@ || 'Error';
    }
  }
  Carp::croak $error if defined $error;
  return $self->with_offset_same_local($offset / 60);
}

sub with_system_offset_same_instant {
  my ($self) = @_;
  my $time = $self->epoch;
  my @lt = localtime $time;
  my $offset = do {
    if ($time >= 0) {
      Time::TZOffset::tzoffset_as_seconds(@lt);
    }
    else {
      $lt[5] += 1900;
      Time::Local::timegm_modern(@lt) - $time;
    }
  };
  return $self->with_offset_same_instant($offset / 60);
}

sub with_system_offset_same_local {
  my ($self) = @_;
  my $time = $self->epoch + $self->offset * 60;
  my @lt = gmtime $time;
  my $offset = do {
    if ($time >= 0) {
      Time::TZOffset::tzoffset_as_seconds(@lt);
    }
    else {
      $lt[5] += 1900;
      $time - Time::Local::timelocal_modern(@lt);
    }
  };
  return $self->with_offset_same_local($offset / 60);
}

1;

=pod

=encoding UTF-8

=head1 NAME

Time::Moment::Role::TimeZone::Fast

=cut

__END__

Time::Moment::Role::TimeZone 0.02 をコピーして少し変更したものです。

with_time_zone_offset_same_instant
with_time_zone_offset_same_local
に変更はありません。
$tz->offset_for_datetime($tm) とできるのは、そもそも Time::Moment に
utc_rd_as_seconds
local_rd_as_seconds
が備わっているからです。

with_system_offset_same_instant
with_system_offset_same_local
は Time::TZOffset と Time::Local とで、正しく速く計算できる方を使っています。
Time::TZOffset は epoch がマイナスになると結果に誤りがあります。
Time::Local の _modern 系は正しく計算できます。
