use strict;
use Test::More;
use Test::Exception;

plan skip_all => "DateTime is not installed." unless eval { require DateTime };

require_ok "Time::Moment";
require_ok "Time::MomentX::BOKUTIN";

sub tmx { Time::MomentX::BOKUTIN::tmx(@_) }

{
    my $str1 = "2019-01-26T12:00:00+0000";
    my $str2 = "2019-01-26T12:00:00+0900";
    my $dt1  = DateTime->new( year => 2019, month => 1, day => 26, hour => 12, time_zone => "UTC" );
    my $dt2  = DateTime->new( year => 2019, month => 1, day => 26, hour => 12, time_zone => "Asia/Tokyo" );

    is $dt1->strftime("%Y-%m-%dT%H:%M:%S%z"), $str1;
    is $dt2->strftime("%Y-%m-%dT%H:%M:%S%z"), $str2;
    is Time::Moment->from_object($dt1), "2019-01-26T12:00:00Z";
    is Time::Moment->from_object($dt2), "2019-01-26T12:00:00+09:00";
    is tmx( from_object => $dt1 ), "2019-01-26T12:00:00Z";
    is tmx( from_object => $dt2 ), "2019-01-26T12:00:00+09:00";
}

{
    my $str1 = "2019-01-26T12:00:00+0000";
    my $dt1  = DateTime->new( year => 2019, month => 1, day => 26, hour => 12 );

    is $dt1->strftime("%Y-%m-%dT%H:%M:%S%z"), $str1;

    throws_ok {
        Time::Moment->from_object($dt1);
    } qr/Cannot coerce an instance of DateTime in the 'floating' time zone to an instance/;
    lives_ok {
        my $dt2 = $dt1->clone;
        $dt2->set_time_zone('local');
        Time::Moment->from_object($dt2);
    };

    is tmx( from_object => $dt1 ), "2019-01-26T12:00:00+09:00";
}

done_testing;
