use Test::More;

use utf8;
use strict;
use warnings;
use feature qw(:5.10);
use POSIX qw(:locale_h);
use Time::Local ();

require_ok "Time::MomentX::BOKUTIN";

my $class = Time::MomentX::BOKUTIN::tmx();
sub tmx { Time::MomentX::BOKUTIN::tmx(@_) }

$ENV{TZ} = 'Asia/Tokyo';
POSIX::tzset();

is tmx->from_epoch(0), "1970-01-01T00:00:00Z";
is tmx->from_epoch(0)->with_system_offset_same_instant, "1970-01-01T09:00:00+09:00";
is tmx(0),                                              "1970-01-01T09:00:00+09:00";
is tmx(from_epoch=>0),                                  "1970-01-01T09:00:00+09:00";

is tmx(from_epoch=>0)->epoch, 0;

# 下は Time::MomentX::Role::TimeZone だとパスしなかった
is tmx->from_epoch(0-24*60*60), "1969-12-31T00:00:00Z";
is tmx->from_epoch(0-24*60*60)->with_system_offset_same_instant, "1969-12-31T09:00:00+09:00";

is tmx("1970-01"), "1970-01-01T00:00:00+09:00";
is tmx("1970-01")->epoch, -9*60*60;

is tmx( from_rd  => int tmx("1970-01")->rd  ), "1970-01-01T00:00:00+09:00";
is tmx( from_jd  => int tmx("1970-01")->jd  ), "1969-12-31T21:00:00+09:00";
is tmx( from_mjd => int tmx("1970-01")->mjd ), "1969-12-31T09:00:00+09:00";

#################

{
    require DateTime::TimeZone;
    my $tz = DateTime::TimeZone->new( name => "Asia/Taipei" ); # +08:00

    my $offset = $tz->offset_for_datetime(tmx('2010-01-01'));

    is tmx('2010-01-01'), "2010-01-01T00:00:00+09:00";
    is tmx('2010-01-01')->with_offset_same_local($offset/60),   "2010-01-01T00:00:00+08:00";
    is tmx('2010-01-01')->with_offset_same_instant($offset/60), "2009-12-31T23:00:00+08:00";
}

done_testing;
