use Test::More;

use utf8;
use strict;
use warnings;
use feature qw(:5.10);
use POSIX qw(:locale_h);
use Time::Moment;
use Time::Local ();
use Time::TZOffset qw(tzoffset tzoffset_as_seconds);

$ENV{TZ} = 'Asia/Tokyo';
POSIX::tzset();

my @lt0 = (0, 0, 0 , 1,  0,   70, 4,   0, 0); # epoch 0
my @lt1 = (0, 0, 0, 31, 11,   69, 3, 364, 0); # ecoch 0 - 1days
my @lt2 = (0, 0, 0, 31, 11, 2069, 3, 364, 0); # ecoch 0 - 1days
my @lt3 = do {
    my $tm = Time::Moment->from_rd(1);
    ($tm->second, $tm->minute, $tm->hour, $tm->day_of_month, $tm->month-1, $tm->year-1970, $tm->day_of_week-1, $tm->day_of_year-1, 0);
};
my @lt4 = (0, 0, 0, 31, 11, 2069, 3, 364, 0); # ecoch 0 - 1days

{
    is   Time::Local::timegm_nocheck(@lt0), 0;
    isnt Time::Local::timegm_nocheck(@lt1), -24*60*60; # 69 は 2069 として解釈されてしまうらしい
    is   Time::Local::timegm_nocheck(@lt1), Time::Local::timegm_modern(@lt2);
}

{
    is   tzoffset_as_seconds(@lt0), 9*60*60;
    is   tzoffset_as_seconds(@lt1), 9*60*60;
    is   tzoffset_as_seconds(@lt2), 9*60*60;
    isnt tzoffset_as_seconds(@lt3), 9*60*60; # 動かない
}

sub offset {
    my @lt = @_;
    $lt[5] += 1900;
    my $gm     = Time::Local::timelocal_modern(@lt);
    my $local  = Time::Local::timegm_modern(@lt);
    my $offset = $local - $gm;
}

{
    is   offset(@lt0), 9*60*60;
    is   offset(@lt1), 9*60*60;
    is   offset(@lt2), 9*60*60;
    isnt offset(@lt3), 9*60*60; # 動かない
}

done_testing;
